public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH] x86-64: reduce boot fixmap space
@ 2008-08-29 12:14 Jan Beulich
  2008-09-06 17:50 ` Ingo Molnar
  0 siblings, 1 reply; 2+ messages in thread
From: Jan Beulich @ 2008-08-29 12:14 UTC (permalink / raw)
  To: mingo, tglx, hpa; +Cc: linux-kernel

Just like for 32-bit - as 256 entries are needed, aligning to a
256-entry boundary is sufficient and still guarantees the single pte
table requirement.

Likewise move up __end_of_permanent_fixed_addresses, to match 32-bit.

Signed-off-by: Jan Beulich <jbeulich@novell.com>

---
 include/asm-x86/fixmap_64.h |    8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

--- linux-2.6.27-rc5/include/asm-x86/fixmap_64.h	2008-08-29 10:53:26.000000000 +0200
+++ 2.6.27-rc5-x86_64-btmap-fixmap/include/asm-x86/fixmap_64.h	2008-08-22 15:24:33.000000000 +0200
@@ -49,6 +49,7 @@ enum fixed_addresses {
 #ifdef CONFIG_PARAVIRT
 	FIX_PARAVIRT_BOOTMAP,
 #endif
+	__end_of_permanent_fixed_addresses,
 #ifdef CONFIG_ACPI
 	FIX_ACPI_BEGIN,
 	FIX_ACPI_END = FIX_ACPI_BEGIN + FIX_ACPI_PAGES - 1,
@@ -56,18 +57,17 @@ enum fixed_addresses {
 #ifdef CONFIG_PROVIDE_OHCI1394_DMA_INIT
 	FIX_OHCI1394_BASE,
 #endif
-	__end_of_permanent_fixed_addresses,
 	/*
 	 * 256 temporary boot-time mappings, used by early_ioremap(),
 	 * before ioremap() is functional.
 	 *
 	 * We round it up to the next 512 pages boundary so that we
 	 * can have a single pgd entry and a single pte table:
 	 */
 #define NR_FIX_BTMAPS		64
 #define FIX_BTMAPS_NESTING	4
-	FIX_BTMAP_END = __end_of_permanent_fixed_addresses + 512 -
-			(__end_of_permanent_fixed_addresses & 511),
+	FIX_BTMAP_END = __end_of_permanent_fixed_addresses + 256 -
+			(__end_of_permanent_fixed_addresses & 255),
 	FIX_BTMAP_BEGIN = FIX_BTMAP_END + NR_FIX_BTMAPS*FIX_BTMAPS_NESTING - 1,
 	__end_of_fixed_addresses
 };




^ permalink raw reply	[flat|nested] 2+ messages in thread

* Re: [PATCH] x86-64: reduce boot fixmap space
  2008-08-29 12:14 [PATCH] x86-64: reduce boot fixmap space Jan Beulich
@ 2008-09-06 17:50 ` Ingo Molnar
  0 siblings, 0 replies; 2+ messages in thread
From: Ingo Molnar @ 2008-09-06 17:50 UTC (permalink / raw)
  To: Jan Beulich; +Cc: tglx, hpa, linux-kernel


* Jan Beulich <jbeulich@novell.com> wrote:

> Just like for 32-bit - as 256 entries are needed, aligning to a
> 256-entry boundary is sufficient and still guarantees the single pte
> table requirement.
> 
> Likewise move up __end_of_permanent_fixed_addresses, to match 32-bit.
> 
> Signed-off-by: Jan Beulich <jbeulich@novell.com>

applied to tip/x86/core, thanks Jan.

	Ingo

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2008-09-06 17:50 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -56,18 +57,17 @@ enum fixed_addresses {
 	 * before ioremap() is functional.
 	 *
-	 * We round it up to the next 512 pages boundary so that we
+	 * We round it up to the next 256 pages boundary so that we
 	 * can have a single pgd entry and a single pte table:
 	 */
2008-08-29 12:14 [PATCH] x86-64: reduce boot fixmap space Jan Beulich
2008-09-06 17:50 ` Ingo Molnar

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox